import * as React from 'react';
import { AccessibilityRole, AccessibilityState, StyleProp, TextStyle, ViewStyle } from 'react-native';
import SafeAreaView from 'react-native-safe-area-view';
import Animated from 'react-native-reanimated';
export declare type Route = {
    key: string;
    routeName: string;
} & (NavigationState | undefined);
export declare type NavigationEventName = 'willFocus' | 'didFocus' | 'willBlur' | 'didBlur';
export declare type NavigationState = {
    key: string;
    index: number;
    routes: Route[];
    isTransitioning?: boolean;
    params?: {
        [key: string]: unknown;
    };
};
export declare type NavigationProp<RouteName = string, Params = object> = {
    emit(eventName: string): void;
    navigate(routeName: RouteName): void;
    goBack(): void;
    goBack(key: string | null): void;
    addListener: (event: NavigationEventName, callback: () => void) => {
        remove: () => void;
    };
    isFocused(): boolean;
    state: NavigationState;
    setParams(params: Params): void;
    getParam(): Params;
    dispatch(action: {
        type: string;
    }): boolean;
    dangerouslyGetParent(): NavigationProp | undefined;
};
export declare type ThemedColor = string | {
    light: string;
    dark: string;
};
export declare type Orientation = 'horizontal' | 'vertical';
export declare type LabelPosition = 'beside-icon' | 'below-icon';
export declare type BottomTabBarOptions = {
    keyboardHidesTabBar?: boolean;
    activeTintColor?: ThemedColor;
    inactiveTintColor?: ThemedColor;
    activeBackgroundColor?: ThemedColor;
    inactiveBackgroundColor?: ThemedColor;
    allowFontScaling?: boolean;
    showLabel?: boolean;
    showIcon?: boolean;
    labelStyle?: StyleProp<TextStyle>;
    tabStyle?: StyleProp<ViewStyle>;
    labelPosition?: LabelPosition | ((options: {
        deviceOrientation: Orientation;
    }) => LabelPosition);
    adaptive?: boolean;
    style?: StyleProp<ViewStyle>;
};
export declare type BottomTabBarProps = BottomTabBarOptions & {
    navigation: NavigationProp;
    onTabPress: (props: {
        route: Route;
    }) => void;
    onTabLongPress: (props: {
        route: Route;
    }) => void;
    getAccessibilityLabel: (props: {
        route: Route;
    }) => string | undefined;
    getAccessibilityRole: (props: {
        route: Route;
    }) => AccessibilityRole | undefined;
    getAccessibilityStates: (props: {
        route: Route;
        focused: boolean;
    }) => AccessibilityState[];
    getButtonComponent: (props: {
        route: Route;
    }) => React.ComponentType<any> | undefined;
    getLabelText: (props: {
        route: Route;
    }) => ((scene: {
        focused: boolean;
        tintColor?: string;
        orientation?: 'horizontal' | 'vertical';
    }) => string | undefined) | string | undefined;
    getTestID: (props: {
        route: Route;
    }) => string | undefined;
    renderIcon: (props: {
        route: Route;
        focused: boolean;
        tintColor?: string;
        horizontal?: boolean;
    }) => React.ReactNode;
    dimensions: {
        width: number;
        height: number;
    };
    isLandscape: boolean;
    safeAreaInset?: React.ComponentProps<typeof SafeAreaView>['forceInset'];
    jumpTo: (key: string) => void;
    screenProps: unknown;
};
export declare type MaterialTabBarOptions = {
    activeTintColor?: string;
    allowFontScaling?: boolean;
    bounces?: boolean;
    inactiveTintColor?: string;
    pressColor?: string;
    pressOpacity?: number;
    scrollEnabled?: boolean;
    showIcon?: boolean;
    showLabel?: boolean;
    upperCaseLabel?: boolean;
    tabStyle?: StyleProp<ViewStyle>;
    indicatorStyle?: StyleProp<ViewStyle>;
    iconStyle?: StyleProp<ViewStyle>;
    labelStyle?: StyleProp<TextStyle>;
    contentContainerStyle?: StyleProp<ViewStyle>;
    style?: StyleProp<ViewStyle>;
};
export declare type MaterialTabBarProps = MaterialTabBarOptions & {
    layout: {
        width: number;
        height: number;
    };
    position: Animated.Node<number>;
    jumpTo: (key: string) => void;
    getLabelText: (scene: {
        route: Route;
    }) => ((scene: {
        focused: boolean;
        tintColor: string;
    }) => string | undefined) | string | undefined;
    getAccessible?: (scene: {
        route: Route;
    }) => boolean | undefined;
    getAccessibilityLabel: (scene: {
        route: Route;
    }) => string | undefined;
    getTestID: (scene: {
        route: Route;
    }) => string | undefined;
    renderIcon: (scene: {
        route: Route;
        focused: boolean;
        tintColor: string;
        horizontal?: boolean;
    }) => React.ReactNode;
    renderBadge?: (scene: {
        route: Route;
    }) => React.ReactNode;
    onTabPress?: (scene: {
        route: Route;
    }) => void;
    onTabLongPress?: (scene: {
        route: Route;
    }) => void;
    tabBarPosition?: 'top' | 'bottom';
    screenProps: unknown;
    navigation: NavigationProp;
};
export declare type NavigationCommonTabOptions = {
    title?: string;
    tabBarLabel?: React.ReactNode;
    tabBarVisible?: boolean;
    tabBarAccessibilityLabel?: string;
    tabBarTestID?: string;
    tabBarIcon?: React.ReactNode | ((props: {
        focused: boolean;
        tintColor?: string;
        horizontal?: boolean;
    }) => React.ReactNode);
    tabBarOnPress?: (props: {
        navigation: NavigationProp;
        defaultHandler: () => void;
    }) => void;
    tabBarOnLongPress?: (props: {
        navigation: NavigationProp;
        defaultHandler: () => void;
    }) => void;
};
export declare type NavigationBottomTabOptions = NavigationCommonTabOptions & {
    tabBarButtonComponent?: React.ComponentType<BottomTabBarProps>;
};
export declare type NavigationMaterialTabOptions = NavigationCommonTabOptions & {
    tabBarButtonComponent?: React.ComponentType<any>;
    swipeEnabled?: boolean | ((state: NavigationState) => boolean);
};
export declare type SceneDescriptor<Options extends NavigationCommonTabOptions> = {
    key: string;
    options: Options;
    navigation: NavigationProp;
    getComponent(): React.ComponentType;
};
export declare type Screen<Options extends NavigationCommonTabOptions> = React.ComponentType<any> & {
    navigationOptions?: Options & {
        [key: string]: any;
    };
};
